@@ -3,6 +3,12 @@ use Test::Class::Most parent => 'Mason::Test::Class';
 
 sub test_dollardot : Tests {
     my $self = shift;
+    $self->add_comp(
+        path => '/helper.mi',
+        src  => '%% has "foo";
+Helper: <% $.foo %>
+',
+    );
     $self->test_comp(
         src => '
 <%args>
@@ -10,6 +16,7 @@ $.name => "Joe"
 </%args>
 
 <%shared>
+$.compname
 $.date
 </%shared>
 
@@ -19,12 +26,20 @@ Hello, <% $.name %>. Today is <% $.date %>.
 
 % $.greet();
 
+<& $.compname, foo => $.date &>
+<& /helper.mi, foo => $.name &>
+
 <%init>
 $.date("March 5th");
+$.compname("helper.mi");
 </%init>
 ',
         expect => '
 Hello, Joe. Today is March 5th.
+
+Helper: March 5th
+
+Helper: Joe
 ',
     );
 }
