@@ -1,14 +1,8 @@
 package Mason::t::Interp;
-BEGIN {
-  $Mason::t::Interp::VERSION = '2.06';
-}
 use Test::Class::Most parent => 'Mason::Test::Class';
 use Capture::Tiny qw(capture);
 
-{ package MyInterp;
-BEGIN {
-  $MyInterp::VERSION = '2.06';
-} use Moose; extends 'Mason::Interp' }
+{ package MyInterp; use Moose; extends 'Mason::Interp' }
 
 sub test_base_interp_class : Tests {
     my $self = shift;
